==> haskell-geniplate-mirror-0.7.2-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-geniplate-mirror/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: geniplate-mirror
version: 0.7.2
id: geniplate-mirror-0.7.2-7a7b08f04817589b67dccc165ce3e1a1
key: genip_7ErEQl1MAQSIXHXZ6yd6gk
license: BSD3
copyright: 2014-2015 Lennart Augustsson
maintainer: Dan Rosén, danr@chalmers.se
stability: experimental
homepage: https://github.com/danr/geniplate
synopsis: Use Template Haskell to generate Uniplate-like functions.
description:
    Use Template Haskell to generate Uniplate-like functions.
    .
    This is a maintained mirror of the
    <http://hackage.haskell.org/package/geniplate geniplate> package,
    written by Lennart Augustsson.
category: Generics
author: Lennart Augustsson
exposed: True
exposed-modules:
    Data.Generics.Geniplate
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/geniplate-mirror-0.7.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/geniplate-mirror-0.7.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/geniplate-mirror-0.7.2
hs-libraries: HSgeniplate-mirror-0.7.2-7ErEQl1MAQSIXHXZ6yd6gk
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
haddock-interfaces: /usr/share/doc/haskell-geniplate-mirror/html/geniplate-mirror.haddock
haddock-html: /usr/share/doc/haskell-geniplate-mirror/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-geniplate-mirror-0.7.4-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-geniplate-mirror/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: geniplate-mirror
version: 0.7.4
id: geniplate-mirror-0.7.4-ac9e93ba5f750387756229067293dc8c
key: genip_6lhOxdw8zKrBJy1tqByNGI
license: BSD3
copyright: 2014-2015 Lennart Augustsson
maintainer: Dan Rosén, danr@chalmers.se
stability: experimental
homepage: https://github.com/danr/geniplate
synopsis: Use Template Haskell to generate Uniplate-like functions.
description:
    Use Template Haskell to generate Uniplate-like functions.
    .
    This is a maintained mirror of the
    <http://hackage.haskell.org/package/geniplate geniplate> package,
    written by Lennart Augustsson.
category: Generics
author: Lennart Augustsson
exposed: True
exposed-modules:
    Data.Generics.Geniplate
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/geniplate-mirror-0.7.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/geniplate-mirror-0.7.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/geniplate-mirror-0.7.4
hs-libraries: HSgeniplate-mirror-0.7.4-6lhOxdw8zKrBJy1tqByNGI
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
haddock-interfaces: /usr/share/doc/haskell-geniplate-mirror/html/geniplate-mirror.haddock
haddock-html: /usr/share/doc/haskell-geniplate-mirror/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
